@@ -53,7 +53,7 @@ import apport.REThread
 from apport.packaging_impl import impl as packaging
 from apport.user_group import get_process_user_and_group
 
-__version__ = "2.31.0"
+__version__ = "2.32.0"
 
 
 symptom_script_dir = os.environ.get("APPORT_SYMPTOMS_DIR", "/usr/share/apport/symptoms")
@@ -121,6 +121,11 @@ def _get_users_environ(uid: int) -> dict[str, str]:
     }
 
 
+def has_display() -> bool:
+    """Check if a display server is specified in the environment."""
+    return bool(os.environ.get("DISPLAY") or os.environ.get("WAYLAND_DISPLAY"))
+
+
 def run_as_real_user(
     args: list[str], *, get_user_env: bool = False, **kwargs: Any
 ) -> None:
@@ -528,7 +533,7 @@ class UserInterface:
                 )
                 sys.exit(1)
             elif error.errno == errno.EIO:
-                self.ui_error_message(_("Invalid problem report"), error.strerror)
+                self.ui_error_message(_("Invalid problem report"), str(error.strerror))
                 sys.exit(1)
             raise
 
@@ -1232,11 +1237,10 @@ class UserInterface:
         # report wasn't loaded, so count manually
         size = 0
         for k in self.report:
-            if self.report[k]:
-                try:
-                    size += self.report[k].get_on_disk_size()
-                except AttributeError:
-                    size += len(self.report[k])
+            try:
+                size += self.report[k].get_on_disk_size()
+            except AttributeError:
+                size += len(self.report[k])
         return size
 
     def get_reduced_size(self) -> int:
@@ -1245,11 +1249,10 @@ class UserInterface:
         size = 0
         for k in self.report:
             if k != "CoreDump":
-                if self.report[k]:
-                    try:
-                        size += self.report[k].get_on_disk_size()
-                    except AttributeError:
-                        size += len(self.report[k])
+                try:
+                    size += self.report[k].get_on_disk_size()
+                except AttributeError:
+                    size += len(self.report[k])
 
         return size
 
@@ -1830,7 +1833,7 @@ class UserInterface:
             return False
         except OSError as error:
             self.report = None
-            self.ui_error_message(_("Invalid problem report"), error.strerror)
+            self.ui_error_message(_("Invalid problem report"), str(error.strerror))
             return False
         except (TypeError, ValueError, AssertionError, zlib.error) as error:
             self.report = None
