@@ -83,6 +83,15 @@ def read_shebang(command: str) -> str | None:
     return first_line.decode().split(" ", 1)[0][2:]
 
 
+@contextlib.contextmanager
+def restore_os_environ() -> Generator[None]:
+    """Restore os.environ after leaving this context manager."""
+    orig_env = os.environ.copy()
+    yield
+    os.environ.clear()
+    os.environ.update(orig_env)
+
+
 @contextlib.contextmanager
 def run_test_executable(
     args: Sequence[str] = (os.path.realpath("/bin/sleep"), "86400"),
