@@ -692,8 +692,8 @@ and more
         r = self.crashdb.download(crash_id)
         self.assertNotIn("CoreDump", r)
 
-    @unittest.mock.patch.object(CrashDatabase, "_get_source_version", MagicMock())
-    def test_get_fixed_version(self):
+    @unittest.mock.patch.object(CrashDatabase, "_get_source_version")
+    def test_get_fixed_version(self, get_source_version_mock: MagicMock) -> None:
         """get_fixed_version() for fixed bugs
 
         Other cases are already checked in test_marking_segv() (invalid
@@ -701,12 +701,14 @@ and more
         """
         # staging.launchpad.net often does not have Quantal, so mock-patch
         # it to a known value
-        CrashDatabase._get_source_version.return_value = "3.14"
+        get_source_version_mock.return_value = "3.14"
         self._mark_report_fixed(self.get_segv_report())
         fixed_ver = self.crashdb.get_fixed_version(self.get_segv_report())
         self.assertEqual(fixed_ver, "3.14")
+        get_source_version_mock.assert_called_with("coreutils")
         self._mark_report_new(self.get_segv_report())
         self.assertIsNone(self.crashdb.get_fixed_version(self.get_segv_report()))
+        get_source_version_mock.assert_called_with("coreutils")
 
     #
     # Launchpad specific implementation and tests
@@ -912,14 +914,14 @@ NameError: global name 'weird' is not defined"""
         # needs to have 13 consecutive valid bugs without dupes
         first_dup = 10070
         try:
-            for b in range(first_dup, first_dup + 13):
+            for bug_id in range(first_dup, first_dup + 13):
                 count += 1
-                sys.stderr.write(f"{b} ")
-                db.close_duplicate(Report(), b, self.get_segv_report())
-                b = db.launchpad.bugs[self.get_segv_report()]
-                has_escalation_tag = db.options["escalation_tag"] in b.tags
+                sys.stderr.write(f"{bug_id} ")
+                db.close_duplicate(Report(), bug_id, self.get_segv_report())
+                bug = db.launchpad.bugs[self.get_segv_report()]
+                has_escalation_tag = db.options["escalation_tag"] in bug.tags
                 has_escalation_subscription = any(
-                    s.person_link == p for s in b.subscriptions
+                    s.person_link == p for s in bug.subscriptions
                 )
                 if count <= 10:
                     self.assertFalse(has_escalation_tag)
@@ -928,9 +930,9 @@ NameError: global name 'weird' is not defined"""
                     self.assertTrue(has_escalation_tag)
                     self.assertTrue(has_escalation_subscription)
         finally:
-            for b in range(first_dup, first_dup + count):
-                sys.stderr.write(f"R{b} ")
-                db.close_duplicate(Report(), b, None)
+            for bug_id in range(first_dup, first_dup + count):
+                sys.stderr.write(f"R{bug_id} ")
+                db.close_duplicate(Report(), bug_id, None)
         sys.stderr.write("\n")
 
     def test_marking_python_task_mangle(self) -> None:
