@@ -3,14 +3,17 @@
 # TODO: Address following pylint complaints
 # pylint: disable=invalid-name
 
+import glob
 import os
 import pwd
+import re
 import shutil
 import sys
 import tempfile
 import time
 import unittest
 import unittest.mock
+from collections.abc import Iterator
 from unittest.mock import MagicMock
 
 import apport.fileutils
@@ -61,11 +64,29 @@ class T(unittest.TestCase):
             return [r1, r2, ri]
         return [r1, r2]
 
-    def test_find_package_desktopfile(self) -> None:
-        # TODO: Split into smaller functions/methods
-        # pylint: disable=too-many-branches
-        """find_package_desktopfile()"""
-        # package without any .desktop file
+    @staticmethod
+    def _packages_with_desktop_files() -> Iterator[tuple[str, int, int]]:
+        desktop_path_re = re.compile("^/usr/share/applications/[^/]+.desktop$")
+        for path in sorted(glob.glob("/usr/share/applications/*.desktop")):
+            pkg = apport.packaging.get_file_package(path)
+            if pkg is None:
+                continue
+
+            display_num = 0
+            no_display_num = 0
+            for desktop_file in apport.packaging.get_files(pkg):
+                if not desktop_path_re.match(desktop_file):
+                    continue
+                with open(desktop_file, "rb") as desktop_file:
+                    if b"NoDisplay=true" in desktop_file.read():
+                        no_display_num += 1
+                    else:
+                        display_num += 1
+
+            yield (pkg, display_num, no_display_num)
+
+    def test_find_package_desktopfile_none(self) -> None:
+        """find_package_desktopfile() for a package without any .desktop file"""
         nodesktop = "bash"
         assert (
             len(
@@ -77,70 +98,53 @@ class T(unittest.TestCase):
             )
             == 0
         )
+        self.assertIsNone(
+            apport.fileutils.find_package_desktopfile(nodesktop),
+            f"no-desktop package {nodesktop}",
+        )
 
-        # find a package with one, a package with multiple .desktop files, and
-        # a package with a NoDisplay .desktop file
-        onedesktop = None
-        multidesktop = None
-        nodisplay = None
-        found_some = False
-        for d in sorted(os.listdir("/usr/share/applications/")):
-            if not d.endswith(".desktop"):
-                continue
-            path = os.path.join("/usr/share/applications/", d)
-            pkg = apport.packaging.get_file_package(path)
-            if pkg is None:
-                continue
-            found_some = True
-
-            display_num = 0
-            no_display_num = 0
-            for desktop_file in apport.packaging.get_files(pkg):
-                if not desktop_file.endswith(".desktop"):
-                    continue
-                if desktop_file.startswith("/usr/share/mimelnk"):
-                    continue
-                with open(desktop_file, "rb") as desktop_file:
-                    if b"NoDisplay=true" in desktop_file.read():
-                        no_display_num += 1
-                    else:
-                        display_num += 1
-
-            if not nodisplay and display_num == 0 and no_display_num == 1:
-                nodisplay = pkg
-            elif not onedesktop and display_num == 1:
+    def test_find_package_desktopfile_one(self) -> None:
+        """find_package_desktopfile() for a package with exactly one .desktop file"""
+        for pkg, display_num, _ in self._packages_with_desktop_files():
+            if display_num == 1:
                 onedesktop = pkg
-            elif not multidesktop and display_num > 1:
-                multidesktop = pkg
-
-            if onedesktop and multidesktop and nodisplay:
                 break
+        else:
+            self.skipTest("no package with exactly one .desktop file found")
 
-        self.assertTrue(found_some)
+        d = apport.fileutils.find_package_desktopfile(onedesktop)
+        self.assertIsNotNone(d, f"one-desktop package {onedesktop}")
+        self.assertTrue(os.path.exists(d))
+        self.assertTrue(d.endswith(".desktop"))
 
-        if nodesktop:
-            self.assertEqual(
-                apport.fileutils.find_package_desktopfile(nodesktop),
-                None,
-                f"no-desktop package {nodesktop}",
-            )
-        if multidesktop:
-            self.assertEqual(
-                apport.fileutils.find_package_desktopfile(multidesktop),
-                None,
-                f"multi-desktop package {multidesktop}",
-            )
-        if onedesktop:
-            d = apport.fileutils.find_package_desktopfile(onedesktop)
-            self.assertIsNotNone(d, f"one-desktop package {onedesktop}")
-            self.assertTrue(os.path.exists(d))
-            self.assertTrue(d.endswith(".desktop"))
-        if nodisplay:
-            self.assertEqual(
-                apport.fileutils.find_package_desktopfile(nodisplay),
-                None,
-                f"NoDisplay package {nodisplay}",
-            )
+    def test_find_package_desktopfile_multiple(self) -> None:
+        """find_package_desktopfile() for a package without multiple .desktop files"""
+        for pkg, display_num, _ in self._packages_with_desktop_files():
+            if display_num > 1:
+                multidesktop = pkg
+                break
+        else:
+            self.skipTest("no package with multiple .desktop files found")
+
+        self.assertIsNone(
+            apport.fileutils.find_package_desktopfile(multidesktop),
+            f"multi-desktop package {multidesktop}",
+        )
+
+    def test_find_package_desktopfile_no_display(self) -> None:
+        """find_package_desktopfile() for a package with a NoDisplay .desktop file"""
+        nodisplay = None
+        for pkg, display_num, no_display_num in self._packages_with_desktop_files():
+            if display_num == 0 and no_display_num == 1:
+                nodisplay = pkg
+                break
+        # expect a package with a NoDisplay .desktop file, e. g. python3.XX
+        assert nodisplay is not None
+
+        self.assertIsNone(
+            apport.fileutils.find_package_desktopfile(nodisplay),
+            f"NoDisplay package {nodisplay}",
+        )
 
     def test_find_file_package(self) -> None:
         """find_file_package()"""
@@ -170,7 +174,7 @@ class T(unittest.TestCase):
         """mark_hanging_process()"""
         pr = problem_report.ProblemReport()
         pr["ExecutablePath"] = "/bin/bash"
-        apport.fileutils.mark_hanging_process(pr, "1")
+        apport.fileutils.mark_hanging_process(pr, 1)
         uid = str(os.getuid())
         base = f"_bin_bash.{uid}.1.hanging"
         expected = os.path.join(apport.fileutils.report_dir, base)
@@ -302,6 +306,15 @@ class T(unittest.TestCase):
         os.symlink(os.path.join(apport.fileutils.report_dir, "pwned"), path)
         self.assertRaises(OSError, apport.fileutils.make_report_file, pr)
 
+    def test_make_report_file_uid_0(self) -> None:
+        """make_report_file(report, uid=0)"""
+        report = problem_report.ProblemReport()
+        report["ExecutablePath"] = "/bin/sh"
+        with apport.fileutils.make_report_file(report, uid=0) as report_file:
+            self.assertEqual(
+                report_file.name, f"{apport.fileutils.report_dir}/_bin_sh.0.crash"
+            )
+
     def test_check_files_md5(self) -> None:
         """check_files_md5()"""
         f1 = os.path.join(apport.fileutils.report_dir, "test 1.txt")
