@@ -8,6 +8,7 @@ import atexit
 import grp
 import io
 import os
+import pathlib
 import re
 import shutil
 import subprocess
@@ -137,7 +138,7 @@ class T(unittest.TestCase):
         self.assertNotIn("UserGroups", report)
         geteuid_mock.assert_called_once_with()
 
-    def test_add_proc_info(self):
+    def test_add_proc_info(self) -> None:
         # TODO: Split into separate test cases
         # pylint: disable=too-many-statements
         """add_proc_info()."""
@@ -236,31 +237,30 @@ class T(unittest.TestCase):
         self.assertIn("[stack]", pr["ProcMaps"])
 
         # check correct handling of interpreted executables: python
-        (fd, testscript) = tempfile.mkstemp()
-        os.write(
-            fd,
-            textwrap.dedent(
-                f"""\
-                #!/usr/bin/{os.getenv('PYTHON', 'python3')}
-                import sys
-                sys.stdin.readline()
-                """
-            ).encode("ascii"),
-        )
-        os.close(fd)
-        os.chmod(testscript, 0o755)
-        with subprocess.Popen(
-            [testscript], stdin=subprocess.PIPE, stderr=subprocess.PIPE
-        ) as process:
-            self.wait_for_proc_cmdline(process.pid)
-            pr = apport.report.Report()
-            pr.add_proc_info(pid=process.pid)
-            process.communicate(b"\n")
-        self.assertEqual(pr["ExecutablePath"], testscript)
-        self.assertEqual(
-            int(pr["ExecutableTimestamp"]), int(os.stat(testscript).st_mtime)
-        )
-        os.unlink(testscript)
+        with tempfile.TemporaryDirectory(prefix="apport_") as tempdir:
+            testscript = pathlib.Path(tempdir) / "testscript.py"
+            testscript.write_text(
+                textwrap.dedent(
+                    f"""\
+                    #!/usr/bin/{os.getenv('PYTHON', 'python3')}
+                    import sys
+                    sys.stdin.readline()
+                    """
+                ),
+                encoding="ascii",
+            )
+            testscript.chmod(0o755)
+            with subprocess.Popen(
+                [str(testscript)], stdin=subprocess.PIPE, stderr=subprocess.PIPE
+            ) as process:
+                self.wait_for_proc_cmdline(process.pid)
+                pr = apport.report.Report()
+                pr.add_proc_info(pid=process.pid)
+                process.communicate(b"\n")
+            self.assertEqual(pr["ExecutablePath"], str(testscript))
+            self.assertEqual(
+                int(pr["ExecutableTimestamp"]), int(testscript.stat().st_mtime)
+            )
         self.assertIn("python", pr["InterpreterPath"])
         self.assertIn("python", pr["ProcMaps"])
         self.assertIn("[stack]", pr["ProcMaps"])
@@ -660,8 +660,7 @@ int main() { return f(42); }
                 fd.write(code)
             try:
                 subprocess.run(
-                    ["gcc"] + extra_gcc_args + ["-g", "crash.c", "-o", "crash"],
-                    check=True,
+                    ["gcc", "-g", "crash.c", "-o", "crash"] + extra_gcc_args, check=True
                 )
             except FileNotFoundError as error:
                 self.skipTest(f"{error.filename} not available")
@@ -985,42 +984,25 @@ int main() { return f(42); }
         self._validate_gdb_fields(pr)
         self.assertNotIn("AssertionMessage", pr)
 
-    # disabled: __glib_assert_msg symbol not available (LP: #1689344)
-    def disabled_test_add_gdb_info_abort_glib(self):
+    def test_add_gdb_info_abort_glib(self):
         """add_gdb_info() with glib assertion"""
-        (fd, script) = tempfile.mkstemp()
-        assert not os.path.exists("core")
+        code = textwrap.dedent(
+            """\
+            #include <glib.h>
+            int main() { g_assert_cmpint(1, <, 0); }
+            """
+        )
         try:
-            os.close(fd)
-
-            # create a test script which produces a core dump for us
-            with open(script, "w", encoding="utf-8") as fd:
-                fd.write(
-                    textwrap.dedent(
-                        """\
-                        #!/bin/sh
-                        gcc -o $0.bin -x c - \
-                            `pkg-config --cflags --libs glib-2.0` <<EOF
-                        #include <glib.h>
-                        int main() { g_assert_cmpint(1, <, 0); }
-                        EOF
-                        ulimit -c unlimited
-                        $0.bin 2>/dev/null
-                        """
-                    )
-                )
-            # call script and verify that it gives us a proper ELF core dump
-            assert subprocess.call(["/bin/sh", script]) != 0
-            self._validate_core("core")
-
-            pr = apport.report.Report()
-            pr["ExecutablePath"] = script + ".bin"
-            pr["CoreDump"] = ("core",)
-            pr.add_gdb_info()
-        finally:
-            os.unlink(script)
-            os.unlink(script + ".bin")
-            os.unlink("core")
+            process = subprocess.run(
+                ["pkg-config", "--cflags", "--libs", "glib-2.0"],
+                check=True,
+                stdout=subprocess.PIPE,
+                text=True,
+            )
+        except FileNotFoundError as error:
+            self.skipTest(f"{error.filename} not available")
+        glib_flags = process.stdout.strip().split()
+        pr = self._generate_sigsegv_report(None, "6", code, None, glib_flags)
 
         self._validate_gdb_fields(pr)
         self.assertTrue(
@@ -1195,7 +1177,7 @@ int main() { return f(42); }
                 None,
                 "does not match on wrong Foo UTF-8 value",
             )
-            r_bash["Foo"] = b"\x01\xFF"
+            r_bash["Foo"] = b"\x01\xff"
             self.assertEqual(
                 r_bash.search_bug_patterns(pattern_url),
                 None,
