@@ -19,6 +19,7 @@ import contextlib
 import datetime
 import grp
 import os
+import pathlib
 import resource
 import shutil
 import signal
@@ -31,7 +32,7 @@ import textwrap
 import time
 import typing
 import unittest
-from collections.abc import Callable, Iterator
+from collections.abc import Callable, Iterable, Iterator
 from pathlib import Path
 from unittest.mock import MagicMock
 
@@ -234,24 +235,24 @@ class T(unittest.TestCase):
 
         self._check_report(expect_report=False)
 
-    def test_crash_apport(self):
+    def test_crash_apport(self) -> None:
         """Report generation with apport."""
-        self.do_crash()
-        st = os.stat(self.test_report)
+        test_report = self.do_crash()
+        st = os.stat(test_report)
 
         # a subsequent crash does not alter unseen report
-        self.do_crash()
-        st2 = os.stat(self.test_report)
+        test_report = self.do_crash()
+        st2 = os.stat(test_report)
         self.assertEqual(st, st2, "original unseen report did not get overwritten")
 
         # a subsequent crash alters seen report
-        apport.fileutils.mark_report_seen(self.test_report)
-        self.do_crash()
-        st2 = os.stat(self.test_report)
+        apport.fileutils.mark_report_seen(test_report)
+        test_report = self.do_crash()
+        st2 = os.stat(test_report)
         self.assertNotEqual(st, st2, "original seen report gets overwritten")
 
         pr = apport.Report()
-        with open(self.test_report, "rb") as f:
+        with open(test_report, "rb") as f:
             pr.load(f)
         self.assertTrue(
             set(required_fields).issubset(set(pr.keys())), "report has required fields"
@@ -381,13 +382,12 @@ class T(unittest.TestCase):
 
     def test_unpackaged_script(self) -> None:
         """Unpackaged scripts do not create a report."""
-        local_exe = os.path.join(self.workdir, "myscript")
-        with open(local_exe, "w", encoding="utf-8") as f:
-            f.write("#!/usr/bin/perl\nsleep(86400);\n")
-        os.chmod(local_exe, 0o755)
+        local_exe = pathlib.Path(self.workdir) / "myscript"
+        local_exe.write_bytes(b"#!/usr/bin/perl\nsleep(86400);\n")
+        local_exe.chmod(0o755)
 
         # absolute path
-        self.do_crash(command=local_exe, args=[], expect_report=False)
+        self.do_crash(command=str(local_exe), args=[], expect_report=False)
 
         self.do_crash(
             command="./myscript", args=[], expect_report=False, cwd=self.workdir
@@ -457,11 +457,11 @@ class T(unittest.TestCase):
         while count < 7:
             sys.stderr.write(f"{count} ")
             sys.stderr.flush()
-            self.do_crash()
+            test_report = self.do_crash()
             reports = apport.fileutils.get_new_reports()
             if not reports:
                 break
-            apport.fileutils.mark_report_seen(self.test_report)
+            apport.fileutils.mark_report_seen(test_report)
             count += 1
         self.assertGreater(count, 1, "gets at least 2 repeated crashes")
         self.assertLess(count, 7, "stops flooding after less than 7 repeated crashes")
@@ -491,17 +491,17 @@ class T(unittest.TestCase):
         for sig in (signal.SIGSEGV, signal.SIGABRT):
             for kb, exp_file in core_ulimit_table:
                 resource.setrlimit(resource.RLIMIT_CORE, (kb, -1))
-                self.do_crash(
+                test_report = self.do_crash(
                     expect_corefile=exp_file,
                     expect_corefile_owner=os.geteuid(),
                     sig=sig,
                 )
-                self.check_report_coredump(self.test_report)
-                apport.fileutils.delete_report(self.test_report)
+                self.check_report_coredump(test_report)
+                apport.fileutils.delete_report(test_report)
 
             # creates core file with existing crash report, too
-            self.do_crash(expect_corefile=True)
-            apport.fileutils.delete_report(self.test_report)
+            test_report = self.do_crash(expect_corefile=True)
+            apport.fileutils.delete_report(test_report)
 
     def test_core_dump_packaged_sigquit(self) -> None:
         """Packaged executables create core files, no report for SIGQUIT."""
@@ -578,14 +578,14 @@ class T(unittest.TestCase):
         # do_crash verifies that we get the original core, not the injected one
         self.do_crash(expect_corefile=True, hook_before_apport=inject_bogus_report)
 
-    def test_ignore(self):
+    def test_ignore(self) -> None:
         """Ignore executables."""
-        self.do_crash()
+        test_report = self.do_crash()
 
         pr = apport.Report()
-        with open(self.test_report, "rb") as f:
+        with open(test_report, "rb") as f:
             pr.load(f)
-        os.unlink(self.test_report)
+        os.unlink(test_report)
 
         pr.mark_ignore()
 
@@ -786,16 +786,16 @@ class T(unittest.TestCase):
                 suid_dumpable=2,
             )
 
-    def test_coredump_from_socket(self):
+    def test_coredump_from_socket(self) -> None:
         """Forward a core dump through a socket.
 
         This is being used in a container via systemd activation, where the
         core dump gets read from /run/apport.socket.
         """
-        self.do_crash(via_socket=True)
+        test_report = self.do_crash(via_socket=True)
 
         pr = apport.Report()
-        with open(self.test_report, "rb") as f:
+        with open(test_report, "rb") as f:
             pr.load(f)
         self.assertEqual(pr["Signal"], "11")
         self.assertEqual(pr["ExecutablePath"], self.TEST_EXECUTABLE)
@@ -811,17 +811,17 @@ class T(unittest.TestCase):
         )
 
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
-    def test_crash_setuid_drop_via_socket(self):
+    def test_crash_setuid_drop_via_socket(self) -> None:
         """Report generation via socket for setuid program which drops root."""
         with create_dropsuid() as dropsuid:
             resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
-            self.do_crash(
+            test_report = self.do_crash(
                 command=dropsuid, uid=MAIL_UID, suid_dumpable=2, via_socket=True
             )
 
             # check crash report
             report = apport.Report()
-            with open(self.test_report, "rb") as report_file:
+            with open(test_report, "rb") as report_file:
                 report.load(report_file)
             self.assertEqual(report["Signal"], "11")
             self.assertEqual(report["ExecutablePath"], dropsuid)
@@ -1118,8 +1118,9 @@ class T(unittest.TestCase):
         hook_before_apport: Callable | None = None,
         expect_report: bool = True,
         via_socket: bool = False,
+        cwd: str | None = None,
         **kwargs: typing.Any,
-    ) -> None:
+    ) -> str:
         # TODO: Split into smaller functions/methods
         # pylint: disable=too-many-branches,too-many-locals,too-many-statements
         """Generate a test crash.
@@ -1144,11 +1145,14 @@ class T(unittest.TestCase):
             command = self.TEST_EXECUTABLE
         if args is None:
             args = self.TEST_ARGS
-        if not os.access(command, os.X_OK):
-            self.skipTest(f"{command} is not executable")
+        if cwd:
+            command_path = os.path.join(cwd, command)
+        else:
+            command_path = command
+        assert os.access(command_path, os.X_OK)
 
         # Support calling scripts in GDB
-        shebang = read_shebang(command)
+        shebang = read_shebang(command_path)
         if shebang:
             args.insert(0, command)
             command = shebang
@@ -1168,6 +1172,7 @@ class T(unittest.TestCase):
                 self.gdb_command(command, args, gdb_core_file, uid),
                 env={"HOME": self.workdir},
                 stdin=subprocess.PIPE,
+                cwd=cwd,
                 **kwargs,
             )
         except FileNotFoundError as error:
@@ -1234,9 +1239,12 @@ class T(unittest.TestCase):
             expect_report=expect_report,
             expected_owner=0 if suid_dumpable == 2 else os.geteuid(),
         )
+        return self.test_report
 
     @staticmethod
-    def gdb_command(command, args, core_file, uid):
+    def gdb_command(
+        command: str, args: Iterable[str], core_file: str, uid: int | None
+    ) -> list[str]:
         """Construct GDB arguments to call the test executable.
 
         GDB must be executed as root for test executables that use setuid.
@@ -1250,15 +1258,17 @@ class T(unittest.TestCase):
         """
         gdb_args = ["gdb", "--quiet", "-iex", "set debuginfod enable off"]
 
-        args = " ".join(f" {a}" for a in args)
+        cmd_args = " ".join(f" {a}" for a in args)
         if uid is not None:
-            args = f" --reuid={uid} --clear-groups /bin/sh -c 'exec {command}{args}'"
+            cmd_args = (
+                f" --reuid={uid} --clear-groups /bin/sh -c 'exec {command}{cmd_args}'"
+            )
             command = "/usr/bin/setpriv"
             gdb_args += ["--ex", "set follow-fork-mode child"]
 
         gdb_args += [
             "--ex",
-            f"run{args}",
+            f"run{cmd_args}",
             "--ex",
             f"generate-core-file {core_file}",
             command,
