@@ -349,6 +349,14 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
         )
         self.assertEqual(len(compressed_value), 65)
 
+    @unittest.skipUnless(zstandard, "zstandard Python module not available")
+    def test_len_zstd_compressed_value_nosize(self) -> None:
+        """Test len() on zstd-compressed CompressedValue without a size header."""
+        compressed_value = problem_report.CompressedValue(
+            compressed_value=base64.b64decode(b"KLUv/QBYEQAAe30=")
+        )
+        self.assertEqual(len(compressed_value), 2)
+
     @unittest.mock.patch("builtins.__import__")
     def test_zstandard_missing(self, import_mock: MagicMock) -> None:
         """Test reading zstd-compressed data when zstandard is missing."""
@@ -772,7 +780,7 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
 
         d = {
             "newtext": "Goodbye world",
-            "newbin": "11\000\001\002\xFFZZ",
+            "newbin": "11\000\001\002\xffZZ",
             "overwrite": "I am good",
         }
 
@@ -780,7 +788,7 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
         self.assertEqual(pr["oldtext"], "Hello world")
         self.assertEqual(pr["oldbin"], bin_data)
         self.assertEqual(pr["newtext"], "Goodbye world")
-        self.assertEqual(pr["newbin"], "11\000\001\002\xFFZZ")
+        self.assertEqual(pr["newbin"], "11\000\001\002\xffZZ")
         self.assertEqual(pr["overwrite"], "I am good")
 
     def test_load_key_filter(self) -> None:
